summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/com/android/managedprovisioning/common/Utils.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/com/android/managedprovisioning/common/Utils.java b/src/com/android/managedprovisioning/common/Utils.java
index 598f3b1f..a2a9d735 100644
--- a/src/com/android/managedprovisioning/common/Utils.java
+++ b/src/com/android/managedprovisioning/common/Utils.java
@@ -176,7 +176,7 @@ public class Utils {
* If mdmComponentName is supplied (not null):
* mdmPackageName is ignored.
* Check that the package of mdmComponentName is installed, that mdmComponentName is a
* receiver in this package, and return it.
*
* Otherwise:
* mdmPackageName must be supplied (not null).
@@ -196,7 +196,7 @@ public class Utils {
PackageInfo pi;
try {
pi = c.getPackageManager().getPackageInfo(mdmPackageName,
- PackageManager.GET_RECEIVERS);
+ PackageManager.GET_RECEIVERS | PackageManager.MATCH_DISABLED_COMPONENTS);
} catch (NameNotFoundException e) {
throw new IllegalProvisioningArgumentException("Mdm "+ mdmPackageName
+ " is not installed. ", e);
@@ -176,7 +176,7 @@ public class Utils {
* mdmPackageName is ignored.
* Check that the package of mdmComponentName is installed, that mdmComponentName is a
- * receiver in this package, and return it.
+ * receiver in this package, and return it. The receiver can be in disabled state.
*
* Otherwise: